% ChristiniORD2011 returns the ORD2011 model with the scaling factors
%    8.09 * Ks
%    1.17 * Kr
%    3.57 * CaL
%    3.05 * NCX
%    1.91 * NaK
%    1.70 * NaL
% as published in Table 1 of Krogh-Madsen, Jacobson, Ortega, Christini (2017)
% "Global Optimization of Ventriclar Myocyte Model to Multi-Variable Objective
% Improves Predictions of Drug-Induced Torsades de Pointes", Frontiers in
% Physiology. doi: 10.3389/fphys.2017.01059
function sys = ChristiniORD2011()
    % construct the default ORD2011 model
    sys = ORD2011();
    
    % extract the default params    
    GKs   = bdGetPar(sys,'GKs');
    GKr   = bdGetPar(sys,'GKr');
    GCaL  = bdGetPar(sys,'PCa');     % GCaL  is PCa in  ORD2011
    PNaCa = bdGetPar(sys,'Gncx');    % PNaCa is Gncx in ORD2011
    PNaK  = bdGetPar(sys,'Pnak');    % PNaK  is Pnak in ORD2011
    GNaL  = bdGetPar(sys,'GNaL');

    % apply the Christini scaling factors
    GKs   = 8.09 * GKs;
    GKr   = 1.17 * GKr;
    GCaL  = 3.57 * GCaL;
    PNaCa = 3.05 * PNaCa;
    PNaK  = 1.91 * PNaK;
    GNaL  = 1.7 * GNaL;

    % update the params is sys
    sys = bdSetPar(sys,'GKs',GKs);
    sys = bdSetPar(sys,'GKr',GKr);
    sys = bdSetPar(sys,'PCa',GCaL);        % GCaL  is PCa in  ORD2011
    sys = bdSetPar(sys,'Gncx',PNaCa);      % PNaCa is Gncx in ORD2011
    sys = bdSetPar(sys,'Pnak',PNaK);       % PNaK  is Pnak in ORD2011
    sys = bdSetPar(sys,'GNaL',GNaL);
end



